Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(255)

Unified Diff: ash/shell_delegate.h

Issue 1890583002: Renaming App List Shower to App List Presenter (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Fix. Created 4 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « ash/shell/shell_delegate_impl.cc ('k') | ash/test/shell_test_api.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: ash/shell_delegate.h
diff --git a/ash/shell_delegate.h b/ash/shell_delegate.h
index 922462900a1c569a59da7d14f451e670be510f80..e3c6f5f98e6d5bfc1154370c350aaabd5e53a0cc 100644
--- a/ash/shell_delegate.h
+++ b/ash/shell_delegate.h
@@ -15,7 +15,7 @@
class GURL;
namespace app_list {
-class AppListShower;
+class AppListPresenter;
class AppListViewDelegate;
}
@@ -113,8 +113,8 @@ class ASH_EXPORT ShellDelegate {
// Opens the |url| in a new browser tab.
virtual void OpenUrl(const GURL& url) = 0;
- // Get the AppListShower. Ownership stays with Chrome.
- virtual app_list::AppListShower* GetAppListShower() = 0;
+ // Get the AppListPresenter. Ownership stays with Chrome.
+ virtual app_list::AppListPresenter* GetAppListPresenter() = 0;
// Creates a new ShelfDelegate. Shell takes ownership of the returned
// value.
« no previous file with comments | « ash/shell/shell_delegate_impl.cc ('k') | ash/test/shell_test_api.h » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698